## 转融资交易汇总

接口：slb_len

描述：转融通融资汇总

限量：单次最大可以提取5000行数据，可循环获取所有历史

积分：2000积分每分钟请求200次，5000积分500次请求

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期（YYYYMMDD格式，下同） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期 |
| ob | float | Y | 期初余额(亿元) |
| auc_amount | float | Y | 竞价成交金额(亿元) |
| repo_amount | float | Y | 再借成交金额(亿元) |
| repay_amount | float | Y | 偿还金额(亿元) |
| cb | float | Y | 期末余额(亿元) |

接口示例

```python
pro = ts.pro_api()

df = pro.slb_len(start_date='20240601', end_date='20240620')
```

数据示例

```python
trade_date    ob auc_amount repo_amount repay_amount     cb
0    20240620  1435.50       None        3.10         3.10  1435.50
```